library sunny_share;

import 'dart:async';

import 'package:flutter/services.dart';
import 'share_models.dart';

export 'share_models.dart';

const MethodChannel _channel =
    MethodChannel('github://SunnyApp/flutter_share_content');

const _events = EventChannel('github://SunnyApp/flutter_share_content_events');

// ignore: non_constant_identifier_names
ShareContract Share = _Share();

abstract class ShareContract {
  Future<ShareResponse> share(
      {required List<ShareItem> items, Duration? timeout});
}

class _Share implements ShareContract {
  final Stream<ShareResponse> events;

  @override
  Future<ShareResponse> share({
    required List<ShareItem> items,
    Duration? timeout = const Duration(hours: 1),
  }) async {
    final result = await _channel.invokeMapMethod(
        "share", ShareRequest(items: items).toMap());
    final shareId = result!["shareId"].toString();
    try {
      if (timeout != null) {
        return await events.timeout(timeout, onTimeout: (sink) {
          sink.add(ShareResponse.timeout(shareId));
        }).firstWhere((res) => res.shareId == shareId);
      } else {
        return events.firstWhere((res) => res.shareId == shareId);
      }
    } on TimeoutException {
      return ShareResponse.timeout(shareId);
    } catch (e) {
      return ShareResponse(
          error: "$e",
          isCompleted: false,
          shareId: "?",
          result: null,
          activityType: null);
    }
  }

  _Share()
      : events = _events
            .receiveBroadcastStream()
            .map((dyn) => ShareResponse.fromMap(dyn));
}
